/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/
#ifndef __SEC14_LPC4357OEM_BB_H
#define __SEC14_LPC4357OEM_BB_H

/******************************************************************************
 * Includes
 *****************************************************************************/
#include "lpc_types.h"

/******************************************************************************
 * Defines and typedefs
 *****************************************************************************/

#define SETTINGS_GPIO_IN    (MD_PLN | MD_EZI)
#define SETTINGS_GPIO_OUT   (MD_PLN         )
#define SETTINGS_SSP        (MD_PLN | MD_EZI)

//***********************************************
//* 14-pos Serial Expansion Connector
//* on LPC4357 OEM base board
//*
//* SPI-SCK  (pin 3) = GPIO29 = P0.15
//* SPI-MOSI (pin 4) = GPIO32 = P0.18
//* SPI-MISO (pin 5) = GPIO31 = P0.17
//* SPI-SSEL (pin 6) = GPIO69 = P9.2       --
//* RxD_inp  (pin 7) = GPIO25_RXD = P0.11
//* TxD_outp (pin 8) = GPIO24_TXD = P0.10
//* pin 11   = GPIO42 = P1.18
//* pin 12   = GPIO72 = P2.21
//* pin 13   = GPIO37_AIN0 = P0.23
//* pin 14   = GPIO38_AIN1 = P0.24
//*
//***********************************************

//9.2 GPIO4[14] FUNC0
#define SEC14_PIN6_INP       (LPC_GPIO_PORT->DIR[4] & (1<<14))
#define SEC14_PIN6_SET_INP   do {scu_pinmux(0x9,  2, SETTINGS_GPIO_IN, FUNC0); LPC_GPIO_PORT->DIR[4] &= ~(1UL << 14);} while (0)
#define SEC14_PIN6_SET_OUTP  do {scu_pinmux(0x9,  2, SETTINGS_GPIO_OUT, FUNC0); LPC_GPIO_PORT->DIR[4] |= (1UL << 14);} while (0)
#define SEC14_PIN6_SET_LOW   (LPC_GPIO_PORT->CLR[4] |= (1<<14))
#define SEC14_PIN6_SET_HIGH  (LPC_GPIO_PORT->SET[4] |= (1<<14))

//2.4 GPIO5[4] FUNC4
#define SEC14_PIN7_INP       (LPC_GPIO_PORT->DIR[5] & (1<<4))
#define SEC14_PIN7_SET_INP   do {scu_pinmux(0x2,  4, SETTINGS_GPIO_IN, FUNC0); LPC_GPIO_PORT->DIR[5] &= ~(1UL << 4);} while (0)
#define SEC14_PIN7_SET_OUTP  do {scu_pinmux(0x2,  4, SETTINGS_GPIO_OUT, FUNC0); LPC_GPIO_PORT->DIR[5] |= (1UL << 4);} while (0)
#define SEC14_PIN7_SET_LOW   (LPC_GPIO_PORT->CLR[5] |= (1<<4))
#define SEC14_PIN7_SET_HIGH  (LPC_GPIO_PORT->SET[5] |= (1<<4))

//9.3 GPIO4[15] FUNC0
#define SEC14_PIN8_INP       (LPC_GPIO_PORT->DIR[4] & (1<<15))
#define SEC14_PIN8_SET_INP   do {scu_pinmux(0x9,  3, SETTINGS_GPIO_IN, FUNC0); LPC_GPIO_PORT->DIR[4] &= ~(1UL << 15);} while (0)
#define SEC14_PIN8_SET_OUTP  do {scu_pinmux(0x9,  3, SETTINGS_GPIO_OUT, FUNC0); LPC_GPIO_PORT->DIR[4] |= (1UL << 15);} while (0)
#define SEC14_PIN8_SET_LOW   (LPC_GPIO_PORT->CLR[4] |= (1<<15))
#define SEC14_PIN8_SET_HIGH  (LPC_GPIO_PORT->SET[4] |= (1<<15))

//9.6 GPIO4[11] FUNC0
#define SEC14_PIN11_INP       (LPC_GPIO_PORT->DIR[4] & (1<<11))
#define SEC14_PIN11_SET_INP   do {scu_pinmux(0x9,  6, SETTINGS_GPIO_IN, FUNC0); LPC_GPIO_PORT->DIR[4] &= ~(1UL << 11);} while (0)
#define SEC14_PIN11_SET_OUTP  do {scu_pinmux(0x9,  6, SETTINGS_GPIO_OUT, FUNC0); LPC_GPIO_PORT->DIR[4] |= (1UL << 11);} while (0)
#define SEC14_PIN11_SET_LOW   (LPC_GPIO_PORT->CLR[4] |= (1<<11))
#define SEC14_PIN11_SET_HIGH  (LPC_GPIO_PORT->SET[4] |= (1<<11))

//4.9 GPIO5[13] FUNC4
#define SEC14_PIN12_INP       (LPC_GPIO_PORT->DIR[5] & (1<<13))
#define SEC14_PIN12_SET_INP   do {scu_pinmux(0x4,  9, SETTINGS_GPIO_IN, FUNC0); LPC_GPIO_PORT->DIR[5] &= ~(1UL << 13);} while (0)
#define SEC14_PIN12_SET_OUTP  do {scu_pinmux(0x4,  9, SETTINGS_GPIO_OUT, FUNC0); LPC_GPIO_PORT->DIR[5] |= (1UL << 13);} while (0)
#define SEC14_PIN12_SET_LOW   (LPC_GPIO_PORT->CLR[5] |= (1<<13))
#define SEC14_PIN12_SET_HIGH  (LPC_GPIO_PORT->SET[5] |= (1<<13))

//ADC1
//#define SEC14_PIN13_INP       (LPC_GPIO0->PIN & (1<<23))
//#define SEC14_PIN13_SET_INP   do {LPC_IOCON->P0_23 &= ~(0x07); LPC_GPIO0->DIR &= ~(1<<23);} while (0)
//#define SEC14_PIN13_SET_OUTP  do {LPC_IOCON->P0_23 &= ~(0x07); LPC_GPIO0->DIR |= (1<<23);} while (0)
//#define SEC14_PIN13_SET_LOW   (LPC_GPIO0->CLR = (1<<23))
//#define SEC14_PIN13_SET_HIGH  (LPC_GPIO0->SET = (1<<23))
//
//ADC2
//#define SEC14_PIN14_INP       (LPC_GPIO0->PIN & (1<<24))
//#define SEC14_PIN14_SET_INP   do {LPC_IOCON->P0_24 &= ~(0x07); LPC_GPIO0->DIR &= ~(1<<24);} while (0)
//#define SEC14_PIN14_SET_OUTP  do {LPC_IOCON->P0_24 &= ~(0x07); LPC_GPIO0->DIR |= (1<<24);} while (0)
//#define SEC14_PIN14_SET_LOW   (LPC_GPIO0->CLR = (1<<24))
//#define SEC14_PIN14_SET_HIGH  (LPC_GPIO0->SET = (1<<24))

#define SEC14_INIT_SPI do {\
	SEC14_PIN6_SET_OUTP; \
	scu_pinmux(0xf,  0, SETTINGS_SSP, FUNC0);\
	scu_pinmux(0xf,  2, SETTINGS_SSP, FUNC2);\
	scu_pinmux(0xf,  3, SETTINGS_SSP, FUNC2);\
	} while(0)

#endif /* end __SEC14_LPC4357OEM_BB_H */
/****************************************************************************
 *                            End Of File
 ****************************************************************************/
