﻿/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include "lpc_types.h"
#include "lpc43xx_scu.h"
#include "lpc43xx_timer.h"
#include "lpc43xx_i2c.h"
#include "lpc43xx_ssp.h"

#include "SEC_LPC4357OEM_BB.h"

/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/

#define UG2828_SET_RESET_OUTPUT SEC14_PIN12_SET_OUTP
#define UG2828_SET_RESET_LOW    SEC14_PIN12_SET_LOW
#define UG2828_SET_RESET_HIGH   SEC14_PIN12_SET_HIGH

#define UG2828_SET_SSEL_OUTPUT  SEC14_PIN6_SET_OUTP
#define UG2828_SET_SSEL_LOW     SEC14_PIN6_SET_LOW
#define UG2828_SET_SSEL_HIGH    SEC14_PIN6_SET_HIGH

#define UG2828_SET_DC_OUTPUT    SEC14_PIN11_SET_OUTP
#define UG2828_SET_DC_LOW       SEC14_PIN11_SET_LOW
#define UG2828_SET_DC_HIGH      SEC14_PIN11_SET_HIGH

#define SSP_PORT (LPC_SSP0)
#define SSP_CLOCK 10000000

/******************************************************************************
 * Public functions
 *****************************************************************************/

/******************************************************************************
 *
 * Description:
 *   BSP initialize function. Must be called before any other BSP related
 *   functions.
 *
 *****************************************************************************/
void bsp_init(void)
{
  SSP_CFG_Type SSP_ConfigStruct;
  TIM_TIMERCFG_Type timerCfg;

  UG2828_SET_RESET_OUTPUT;

  UG2828_SET_SSEL_OUTPUT;
  UG2828_SET_SSEL_HIGH;

  UG2828_SET_DC_OUTPUT;
  UG2828_SET_DC_HIGH;

  SEC14_INIT_SPI;

  // initialize SSP configuration structure to default
  SSP_ConfigStructInit(&SSP_ConfigStruct);

  // set clock rate
  SSP_ConfigStruct.ClockRate = SSP_CLOCK;

  // set number of databits
  SSP_ConfigStruct.Databit = SSP_DATABIT_8;

  // Initialize SSP peripheral with parameter given in structure above
  SSP_Init(SSP_PORT, &SSP_ConfigStruct);

  // Enable SSP peripheral
  SSP_Cmd(SSP_PORT, ENABLE);


  TIM_ConfigStructInit(TIM_TIMER_MODE, &timerCfg);
  TIM_Init(LPC_TIMER0, TIM_TIMER_MODE, &timerCfg);

}

/******************************************************************************
 *
 * Description:
 *   Reset the display
 *
 *****************************************************************************/
void bsp_display_reset(void)
{
  UG2828_SET_RESET_LOW;
  TIM_Waitms(40);
  UG2828_SET_RESET_HIGH;
}


/******************************************************************************
 *
 * Description:
 *   Send a command to the SSD1351 controller
 *
 * Params:
 *   [in] cmd - the command
 *
 *****************************************************************************/
void bsp_ssd1351Command(uint8_t cmd)
{
  uint8_t buf[1];
  SSP_DATA_SETUP_Type sspCfg;

  UG2828_SET_SSEL_LOW;
  buf[0] = cmd;
  UG2828_SET_DC_LOW;

  sspCfg.tx_data = buf;
  sspCfg.rx_data = NULL;
  sspCfg.length  = 1;
  SSP_ReadWrite (SSP_PORT, &sspCfg, SSP_TRANSFER_POLLING);

  UG2828_SET_DC_HIGH;
  UG2828_SET_SSEL_HIGH;
}

/******************************************************************************
 *
 * Description:
 *   Send data the SSD1351 controller
 *
 * Params:
 *   [in] data - data to send
 *
 *****************************************************************************/
void bsp_ssd1351Data(uint8_t data)
{
  uint8_t buf[1];
  SSP_DATA_SETUP_Type sspCfg;

  UG2828_SET_SSEL_LOW;
  buf[0] = data;
  UG2828_SET_DC_HIGH;

  sspCfg.tx_data = buf;
  sspCfg.rx_data = NULL;
  sspCfg.length  = 1;
  SSP_ReadWrite (SSP_PORT, &sspCfg, SSP_TRANSFER_POLLING);

  UG2828_SET_SSEL_HIGH;
}

/******************************************************************************
 *
 * Description:
 *   Delay specified number of milliseconds
 *
 * Params:
 *   [in] ms - number of milliseconds to delay
 *
 *****************************************************************************/
void bsp_delayMs(uint32_t ms)
{
  TIM_Waitms(ms);
}

/******************************************************************************
 *
 * Description:
 *   Delay specified number of microseconds
 *
 * Params:
 *   [in] us - number of microseconds to delay
 *
 *****************************************************************************/
void bsp_delayUs(uint32_t us)
{
  TIM_Waitus(us);
}


