/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include "lpc_types.h"

#include "bsp.h"
#include "UG2828.h"
#include "ssd1351.h"

#include "draw.h"

#include "lpc_helvr10.h"
#include "draw_fonts.h"

#include "img_logo.h"

/******************************************************************************
 * Local Variables
 *****************************************************************************/

static draw_lcd_t lcd;

/******************************************************************************
 * Local Functions
 *****************************************************************************/

static void rainbow(draw_lcd_t *lcd)
{
  // White => 0~15
  draw_fillRectangle(lcd, 0, 0, 15, 127, 0xffff);

  // Yellow => 16~31
  draw_fillRectangle(lcd, 16, 0, 31, 127, 0xffe0);

  // Purple => 32~47
  draw_fillRectangle(lcd, 32, 0, 47, 127, 0xf81f);

  // Cyan => 48~63
  draw_fillRectangle(lcd, 48, 0, 63, 127, 0x07ff);

  // Red => 64~79
  draw_fillRectangle(lcd, 64, 0, 79, 127, 0xF800);

  // Green => 80~95
  draw_fillRectangle(lcd, 80, 0, 95, 127, 0x07E0);

  // Blue => 96~111
  draw_fillRectangle(lcd, 96, 0, 111, 127, 0x001f);

  // Black => 112~127
  draw_fillRectangle(lcd, 112, 0, 127, 127, 0x0000);
}

/******************************************************************************
 * Main method
 *****************************************************************************/

int main (void)
{
  const CHAR name1[]="Embedded";
  const CHAR name2[]="Artists AB";
  const CHAR info[]="EmbeddedArtists.com";

  bsp_init();
  ug2828_init(&lcd);

  while (1) {
    // draw logo
    draw_eaImg(&lcd, 0, 0, (uint16_t*)&_img_logo[0]);

    bsp_delayMs(3000);

    // Fade In/Out (Full Screen)
    ssd1351_fadeOut();
    ssd1351_fadeIn();
    ssd1351_fadeOut();
    ssd1351_fadeIn();
    bsp_delayMs(1000);

    // Scrolling (Partial or Full Screen)
    ssd1351_verticalScroll(0x00,0x01,0x40);
    // Upward - Full Screen
    bsp_delayMs(1000);
    ssd1351_verticalScroll(0x01,0x01,0x40);
    // Downward - Full Screen
    bsp_delayMs(1000);
    ssd1351_deactivateScroll();
    ssd1351_horizontalScroll(0x00,0x01,0x38,0x48,0x01,0x02);
    bsp_delayMs(2000);
    // Rightward - Partial Screen
    ssd1351_horizontalScroll(0x01,0x01,0x38,0x48,0x01,0x02);
    bsp_delayMs(2000);
    // Leftward - Partial Screen
    ssd1351_deactivateScroll();

    // Color Bar (Test Pattern)
    rainbow(&lcd);
    bsp_delayMs(3000);

    // clear screen
    draw_fillRectangle(&lcd, 0, 0, 127, 127, 0x0000);

    draw_rectangle(&lcd, 0, 0, 127, 127, 0xFFFF);
    bsp_delayMs(1000);
    draw_rectangle(&lcd, 16, 16, 111, 111, 0xf800);
    bsp_delayMs(1000);
    draw_rectangle(&lcd, 32, 32, 95, 95, 0x07e0);
    bsp_delayMs(1000);
    draw_rectangle(&lcd, 48, 48, 79, 79, 0x001f);
    bsp_delayMs(1000);

    // text
    draw_fillRectangle(&lcd, 16, 16, 111, 111, 0x0000);
    draw_setFont(&font_helvr10);
    draw_putText(&lcd, 10, 10, (const CHAR*)&name1, 0xffff, 0x0000);
    draw_putText(&lcd, 10, 20, (const CHAR*)&name2, 0xffff, 0x0000);
    draw_putText(&lcd, 10, 35, (const CHAR*)&info, 0xffff, 0x0000);
    bsp_delayMs(3000);

    // clear screen
    draw_fillRectangle(&lcd, 0, 0, 127, 127, 0x0000);
  }



  return 1;
}


